@@ -24,11 +24,10 @@
 #include "collectionmodifyjob.h"
 #include "entitydisplayattribute.h"
 #include "monitor.h"
-#include "pastehelper.h"
+#include "pastehelper_p.h"
 #include "session.h"
 
 #include <kdebug.h>
-#include <klocale.h>
 #include <kurl.h>
 #include <kicon.h>
 
@@ -100,8 +99,10 @@ QVariant CollectionModel::data( const QModelIndex & index, int role ) const
         return KIcon( CollectionUtils::defaultIconName( col ) );
       }
       break;
+    case OldCollectionIdRole: // fall-through
     case CollectionIdRole:
       return col.id();
+    case OldCollectionRole: // fall-through
     case CollectionRole:
       return QVariant::fromValue( col );
   }
@@ -170,11 +171,25 @@ int CollectionModel::rowCount( const QModelIndex & parent ) const
 
 QVariant CollectionModel::headerData( int section, Qt::Orientation orientation, int role ) const
 {
+  const  Q_D( CollectionModel );
+
   if ( section == 0 && orientation == Qt::Horizontal && role == Qt::DisplayRole )
-    return i18nc( "@title:column, name of a thing", "Name" );
+    return d->headerContent;
   return QAbstractItemModel::headerData( section, orientation, role );
 }
 
+bool CollectionModel::setHeaderData( int section, Qt::Orientation orientation, const QVariant &value, int role )
+{
+  Q_D( CollectionModel );
+
+  if ( section == 0 && orientation == Qt::Horizontal && role == Qt::EditRole ) {
+    d->headerContent = value.toString();
+    return true;
+  }
+
+  return false;
+}
+
 bool CollectionModel::setData( const QModelIndex & index, const QVariant & value, int role )
 {
   Q_D( CollectionModel );
