@@ -22,9 +22,10 @@
 #include "agentbase_p.h"
 
 #include "resourceadaptor.h"
-#include "collectionsync.h"
+#include "collectiondeletejob.h"
+#include "collectionsync_p.h"
 #include "itemsync.h"
-#include "resourcescheduler.h"
+#include "resourcescheduler_p.h"
 #include "tracerinterface.h"
 #include "xdgbasedirs_p.h"
 
@@ -36,6 +37,7 @@
 #include "itemmodifyjob.h"
 #include "itemmodifyjob_p.h"
 #include "session.h"
+#include "resourceselectjob_p.h"
 
 #include <kaboutdata.h>
 #include <kcmdlineargs.h>
@@ -58,7 +60,8 @@ class Akonadi::ResourceBasePrivate : public AgentBasePrivate
     ResourceBasePrivate( ResourceBase *parent )
       : AgentBasePrivate( parent ),
         scheduler( 0 ),
-        mItemSyncer( 0 )
+        mItemSyncer( 0 ),
+        mCollectionSyncer( 0 )
     {
       mStatusMessage = defaultReadyMessage();
     }
@@ -81,7 +84,6 @@ class Akonadi::ResourceBasePrivate : public AgentBasePrivate
     }
 
     void slotDeliveryDone( KJob* job );
-
     void slotCollectionSyncDone( KJob *job );
     void slotLocalListDone( KJob *job );
     void slotSynchronizeCollection( const Collection &col );
@@ -90,14 +92,16 @@ class Akonadi::ResourceBasePrivate : public AgentBasePrivate
     void slotItemSyncDone( KJob *job );
 
     void slotPercent( KJob* job, unsigned long percent );
-
-    QString mName;
+    void slotDeleteResourceCollection();
+    void slotDeleteResourceCollectionDone( KJob *job );
+    void slotCollectionDeletionDone( KJob *job );
 
     // synchronize states
     Collection currentCollection;
 
     ResourceScheduler *scheduler;
     ItemSync *mItemSyncer;
+    CollectionSync *mCollectionSyncer;
 };
 
 ResourceBase::ResourceBase( const QString & id )
@@ -107,34 +111,39 @@ ResourceBase::ResourceBase( const QString & id )
 
   new ResourceAdaptor( this );
 
-  const QString name = d->mSettings->value( QLatin1String( "Resource/Name" ) ).toString();
-  if ( !name.isEmpty() )
-    d->mName = name;
-
   d->scheduler = new ResourceScheduler( this );
 
   d->mMonitor->setChangeRecordingEnabled( true );
-  connect( d->mMonitor, SIGNAL(changesAdded()),
-           d->scheduler, SLOT(scheduleChangeReplay()) );
+  connect( d->mMonitor, SIGNAL( changesAdded() ),
+           d->scheduler, SLOT( scheduleChangeReplay() ) );
 
   d->mMonitor->setResourceMonitored( d->mId.toLatin1() );
 
-  connect( d->scheduler, SIGNAL(executeFullSync()),
-           SLOT(retrieveCollections()) );
-  connect( d->scheduler, SIGNAL(executeCollectionTreeSync()),
-           SLOT(retrieveCollections()) );
-  connect( d->scheduler, SIGNAL(executeCollectionSync(Akonadi::Collection)),
-           SLOT(slotSynchronizeCollection(Akonadi::Collection)) );
-  connect( d->scheduler, SIGNAL(executeItemFetch(Akonadi::Item,QSet<QByteArray>)),
-           SLOT(retrieveItem(Akonadi::Item,QSet<QByteArray>)) );
-  connect( d->scheduler, SIGNAL( status( int, QString ) ),
-           SIGNAL( status( int, QString ) ) );
-  connect( d->scheduler, SIGNAL(executeChangeReplay()),
-           d->mMonitor, SLOT(replayNext()) );
+  connect( d->scheduler, SIGNAL( executeFullSync() ),
+           SLOT( retrieveCollections() ) );
+  connect( d->scheduler, SIGNAL( executeCollectionTreeSync() ),
+           SLOT( retrieveCollections() ) );
+  connect( d->scheduler, SIGNAL( executeCollectionSync( const Akonadi::Collection& ) ),
+           SLOT( slotSynchronizeCollection( const Akonadi::Collection& ) ) );
+  connect( d->scheduler, SIGNAL( executeItemFetch( const Akonadi::Item&, const QSet<QByteArray>& ) ),
+           SLOT( retrieveItem( const Akonadi::Item&, const QSet<QByteArray>& ) ) );
+  connect( d->scheduler, SIGNAL( executeResourceCollectionDeletion() ),
+           SLOT( slotDeleteResourceCollection() ) );
+  connect( d->scheduler, SIGNAL( status( int, const QString& ) ),
+           SIGNAL( status( int, const QString& ) ) );
+  connect( d->scheduler, SIGNAL( executeChangeReplay() ),
+           d->mMonitor, SLOT( replayNext() ) );
+  connect( d->scheduler, SIGNAL( fullSyncComplete() ), SIGNAL( synchronized() ) );
+  connect( d->mMonitor, SIGNAL( nothingToReplay() ), d->scheduler, SLOT( taskDone() ) );
+  connect( this, SIGNAL( synchronized() ), d->scheduler, SLOT( taskDone() ) );
+  connect( this, SIGNAL( agentNameChanged( const QString& ) ),
+           this, SIGNAL( nameChanged( const QString& ) ) );
 
   d->scheduler->setOnline( d->mOnline );
   if ( !d->mMonitor->isEmpty() )
     d->scheduler->scheduleChangeReplay();
+
+  new ResourceSelectJob( identifier() );
 }
 
 ResourceBase::~ResourceBase()
@@ -148,34 +157,14 @@ void ResourceBase::synchronize()
 
 void ResourceBase::setName( const QString &name )
 {
-  Q_D( ResourceBase );
-  if ( name == d->mName )
-    return;
-
-  // TODO: rename collection
-  d->mName = name;
-
-  if ( d->mName.isEmpty() || d->mName == d->mId )
-    d->mSettings->remove( QLatin1String( "Resource/Name" ) );
-  else
-    d->mSettings->setValue( QLatin1String( "Resource/Name" ), d->mName );
-
-  d->mSettings->sync();
-
-  emit nameChanged( d->mName );
+  AgentBase::setAgentName( name );
 }
 
 QString ResourceBase::name() const
 {
-  Q_D( const ResourceBase );
-  if ( d->mName.isEmpty() )
-    return d->mId;
-  else
-    return d->mName;
+  return AgentBase::agentName();
 }
 
-static char* sAppName = 0;
-
 QString ResourceBase::parseArguments( int argc, char **argv )
 {
   QString identifier;
@@ -194,14 +183,20 @@ QString ResourceBase::parseArguments( int argc, char **argv )
     exit( 1 );
   }
 
-  sAppName = qstrdup( identifier.toLatin1().constData() );
-  KCmdLineArgs::init( argc, argv, sAppName, 0,
+  QByteArray catalog;
+  char *p = strrchr( argv[0], '/' );
+  if ( p )
+    catalog = QByteArray( p + 1 );
+  else
+    catalog = QByteArray( argv[0] );
+
+  KCmdLineArgs::init( argc, argv, identifier.toLatin1(), catalog,
                       ki18nc("@title, application name", "Akonadi Resource"), "0.1",
                       ki18nc("@title, application description", "Akonadi Resource") );
 
   KCmdLineOptions options;
-  options.add("identifier <argument>",
-              ki18nc("@label, commandline option", "Resource identifier"));
+  options.add( "identifier <argument>",
+               ki18nc("@label, commandline option", "Resource identifier") );
   KCmdLineArgs::addCmdLineOptions( options );
 
   return identifier;
@@ -212,7 +207,6 @@ int ResourceBase::init( ResourceBase *r )
   QApplication::setQuitOnLastWindowClosed( false );
   int rv = kapp->exec();
   delete r;
-  delete[] sAppName;
   return rv;
 }
 
@@ -239,7 +233,7 @@ void ResourceBase::itemRetrieved( const Item &item )
   ItemModifyJob *job = new ItemModifyJob( i );
   // FIXME: remove once the item with which we call retrieveItem() has a revision number
   job->disableRevisionCheck();
-  connect( job, SIGNAL(result(KJob*)), SLOT(slotDeliveryDone(KJob*)) );
+  connect( job, SIGNAL( result( KJob* ) ), SLOT( slotDeliveryDone( KJob* ) ) );
 }
 
 void ResourceBasePrivate::slotDeliveryDone(KJob * job)
@@ -257,12 +251,51 @@ void ResourceBasePrivate::slotDeliveryDone(KJob * job)
   scheduler->taskDone();
 }
 
-void ResourceBase::changeCommitted(const Item& item)
+void ResourceBasePrivate::slotDeleteResourceCollection()
+{
+  Q_Q( ResourceBase );
+
+  CollectionFetchJob *job = new CollectionFetchJob( Collection::root(), CollectionFetchJob::FirstLevel );
+  job->setResource( q->identifier() );
+  connect( job, SIGNAL( result( KJob* ) ), q, SLOT( slotDeleteResourceCollectionDone( KJob* ) ) );
+}
+
+void ResourceBasePrivate::slotDeleteResourceCollectionDone( KJob *job )
+{
+  Q_Q( ResourceBase );
+  if ( job->error() ) {
+    emit q->error( job->errorString() );
+    scheduler->taskDone();
+  } else {
+    const CollectionFetchJob *fetchJob = static_cast<const CollectionFetchJob*>( job );
+
+    if ( !fetchJob->collections().isEmpty() ) {
+      CollectionDeleteJob *job = new CollectionDeleteJob( fetchJob->collections().first() );
+      connect( job, SIGNAL( result( KJob* ) ), q, SLOT( slotCollectionDeletionDone( KJob* ) ) );
+    } else {
+      // there is no resource collection, so just ignore the request
+      scheduler->taskDone();
+    }
+  }
+}
+
+void ResourceBasePrivate::slotCollectionDeletionDone( KJob *job )
+{
+  Q_Q( ResourceBase );
+  if ( job->error() ) {
+    emit q->error( job->errorString() );
+  }
+
+  scheduler->taskDone();
+}
+
+void ResourceBase::changeCommitted( const Item& item )
 {
   Q_D( ResourceBase );
   ItemModifyJob *job = new ItemModifyJob( item );
   job->d_func()->setClean();
   job->disableRevisionCheck(); // TODO: remove, but where/how do we handle the error?
+  job->ignorePayload(); // we only want to reset the dirty flag and update the remote id
   d->changeProcessed();
 }
 
@@ -299,39 +332,87 @@ bool ResourceBase::requestItemDelivery( qint64 uid, const QString & remoteId,
   return true;
 }
 
-void ResourceBase::collectionsRetrieved(const Collection::List & collections)
+void ResourceBase::collectionsRetrieved( const Collection::List & collections )
 {
   Q_D( ResourceBase );
-  CollectionSync *syncer = new CollectionSync( d->mId );
-  syncer->setRemoteCollections( collections );
-  connect( syncer, SIGNAL(result(KJob*)), SLOT(slotCollectionSyncDone(KJob*)) );
+  Q_ASSERT_X( d->scheduler->currentTask().type == ResourceScheduler::SyncCollectionTree ||
+              d->scheduler->currentTask().type == ResourceScheduler::SyncAll,
+              "ResourceBase::collectionsRetrieved()",
+              "Calling collectionsRetrieved() although no collection retrieval is in progress" );
+  if ( !d->mCollectionSyncer ) {
+    d->mCollectionSyncer = new CollectionSync( identifier() );
+    connect( d->mCollectionSyncer, SIGNAL( percent( KJob*, unsigned long ) ), SLOT( slotPercent( KJob*, unsigned long ) ) );
+    connect( d->mCollectionSyncer, SIGNAL( result( KJob* ) ), SLOT( slotCollectionSyncDone( KJob* ) ) );
+  }
+  d->mCollectionSyncer->setRemoteCollections( collections );
 }
 
-void ResourceBase::collectionsRetrievedIncremental(const Collection::List & changedCollections, const Collection::List & removedCollections)
+void ResourceBase::collectionsRetrievedIncremental( const Collection::List & changedCollections,
+                                                    const Collection::List & removedCollections )
 {
   Q_D( ResourceBase );
-  CollectionSync *syncer = new CollectionSync( d->mId );
-  syncer->setRemoteCollections( changedCollections, removedCollections );
-  connect( syncer, SIGNAL(result(KJob*)), SLOT(slotCollectionSyncDone(KJob*)) );
+  Q_ASSERT_X( d->scheduler->currentTask().type == ResourceScheduler::SyncCollectionTree ||
+              d->scheduler->currentTask().type == ResourceScheduler::SyncAll,
+              "ResourceBase::collectionsRetrievedIncremental()",
+              "Calling collectionsRetrievedIncremental() although no collection retrieval is in progress" );
+  if ( !d->mCollectionSyncer ) {
+    d->mCollectionSyncer = new CollectionSync( identifier() );
+    connect( d->mCollectionSyncer, SIGNAL( percent( KJob*, unsigned long ) ), SLOT( slotPercent( KJob*, unsigned long ) ) );
+    connect( d->mCollectionSyncer, SIGNAL( result( KJob* ) ), SLOT( slotCollectionSyncDone( KJob* ) ) );
+  }
+  d->mCollectionSyncer->setRemoteCollections( changedCollections, removedCollections );
 }
 
-void ResourceBasePrivate::slotCollectionSyncDone(KJob * job)
+void ResourceBase::setCollectionStreamingEnabled( bool enable )
+{
+  Q_D( ResourceBase );
+  Q_ASSERT_X( d->scheduler->currentTask().type == ResourceScheduler::SyncCollectionTree ||
+              d->scheduler->currentTask().type == ResourceScheduler::SyncAll,
+              "ResourceBase::setCollectionStreamingEnabled()",
+              "Calling setCollectionStreamingEnabled() although no collection retrieval is in progress" );
+  if ( !d->mCollectionSyncer ) {
+    d->mCollectionSyncer = new CollectionSync( identifier() );
+    connect( d->mCollectionSyncer, SIGNAL( percent( KJob*, unsigned long ) ), SLOT( slotPercent( KJob*, unsigned long ) ) );
+    connect( d->mCollectionSyncer, SIGNAL( result( KJob* ) ), SLOT( slotCollectionSyncDone( KJob* ) ) );
+  }
+  d->mCollectionSyncer->setStreamingEnabled( enable );
+}
+
+void ResourceBase::collectionsRetrievalDone()
+{
+  Q_D( ResourceBase );
+  Q_ASSERT_X( d->scheduler->currentTask().type == ResourceScheduler::SyncCollectionTree ||
+              d->scheduler->currentTask().type == ResourceScheduler::SyncAll,
+              "ResourceBase::collectionsRetrievalDone()",
+              "Calling collectionsRetrievalDone() although no collection retrieval is in progress" );
+  // streaming enabled, so finalize the sync
+  if ( d->mCollectionSyncer ) {
+    d->mCollectionSyncer->retrievalDone();
+  }
+  // user did the sync himself, we are done now
+  else {
+    d->scheduler->taskDone();
+  }
+}
+
+void ResourceBasePrivate::slotCollectionSyncDone( KJob * job )
 {
   Q_Q( ResourceBase );
+  mCollectionSyncer = 0;
   if ( job->error() ) {
     emit q->error( job->errorString() );
   } else {
     if ( scheduler->currentTask().type == ResourceScheduler::SyncAll ) {
       CollectionFetchJob *list = new CollectionFetchJob( Collection::root(), CollectionFetchJob::Recursive );
       list->setResource( mId );
-      q->connect( list, SIGNAL(result(KJob*)), q, SLOT(slotLocalListDone(KJob*)) );
+      q->connect( list, SIGNAL( result( KJob* ) ), q, SLOT( slotLocalListDone( KJob* ) ) );
       return;
     }
   }
   scheduler->taskDone();
 }
 
-void ResourceBasePrivate::slotLocalListDone(KJob * job)
+void ResourceBasePrivate::slotLocalListDone( KJob * job )
 {
   Q_Q( ResourceBase );
   if ( job->error() ) {
@@ -341,6 +422,7 @@ void ResourceBasePrivate::slotLocalListDone(KJob * job)
     foreach ( const Collection &col, cols ) {
       scheduler->scheduleSync( col );
     }
+    scheduler->scheduleFullSyncCompletion();
   }
   scheduler->taskDone();
 }
@@ -373,6 +455,12 @@ void ResourceBase::itemsRetrievalDone()
   }
 }
 
+void ResourceBase::clearCache()
+{
+  Q_D( ResourceBase );
+  d->scheduler->scheduleResourceCollectionDeletion();
+}
+
 Collection ResourceBase::currentCollection() const
 {
   Q_D( const ResourceBase );
@@ -398,7 +486,17 @@ void ResourceBase::synchronizeCollectionTree()
 
 void ResourceBase::cancelTask()
 {
-  d_func()->changeProcessed();
+  Q_D( ResourceBase );
+  switch ( d->scheduler->currentTask().type ) {
+    case ResourceScheduler::FetchItem:
+      itemRetrieved( Item() ); // sends the error reply and
+      break;
+    case ResourceScheduler::ChangeReplay:
+      d->changeProcessed();
+      break;
+    default:
+      d->scheduler->taskDone();
+  }
 }
 
 void ResourceBase::cancelTask( const QString &msg )
@@ -408,16 +506,22 @@ void ResourceBase::cancelTask( const QString &msg )
   emit error( msg );
 }
 
+void ResourceBase::deferTask()
+{
+  Q_D( ResourceBase );
+  d->scheduler->deferTask();
+}
+
 void ResourceBase::doSetOnline( bool state )
 {
   d_func()->scheduler->setOnline( state );
 }
 
-void ResourceBase::synchronizeCollection(qint64 collectionId )
+void ResourceBase::synchronizeCollection( qint64 collectionId )
 {
-  CollectionFetchJob* job = new CollectionFetchJob( Collection(collectionId), CollectionFetchJob::Base );
+  CollectionFetchJob* job = new CollectionFetchJob( Collection( collectionId ), CollectionFetchJob::Base );
   job->setResource( identifier() );
-  connect( job, SIGNAL(result(KJob*)), SLOT(slotCollectionListDone(KJob*)) );
+  connect( job, SIGNAL( result( KJob* ) ), SLOT( slotCollectionListDone( KJob* ) ) );
 }
 
 void ResourceBasePrivate::slotCollectionListDone( KJob *job )
@@ -448,8 +552,8 @@ void ResourceBase::setItemStreamingEnabled( bool enable )
               "Calling setItemStreamingEnabled() although no item retrieval is in progress" );
   if ( !d->mItemSyncer ) {
     d->mItemSyncer = new ItemSync( currentCollection() );
-    connect( d->mItemSyncer, SIGNAL(percent(KJob*,unsigned long)), SLOT(slotPercent(KJob*,unsigned long)) );
-    connect( d->mItemSyncer, SIGNAL(result(KJob*)), SLOT(slotItemSyncDone(KJob*)) );
+    connect( d->mItemSyncer, SIGNAL( percent( KJob*, unsigned long ) ), SLOT( slotPercent( KJob*, unsigned long ) ) );
+    connect( d->mItemSyncer, SIGNAL( result( KJob* ) ), SLOT( slotItemSyncDone( KJob* ) ) );
   }
   d->mItemSyncer->setStreamingEnabled( enable );
 }
@@ -462,13 +566,13 @@ void ResourceBase::itemsRetrieved( const Item::List &items )
               "Calling itemsRetrieved() although no item retrieval is in progress" );
   if ( !d->mItemSyncer ) {
     d->mItemSyncer = new ItemSync( currentCollection() );
-    connect( d->mItemSyncer, SIGNAL(percent(KJob*,unsigned long)), SLOT(slotPercent(KJob*,unsigned long)) );
-    connect( d->mItemSyncer, SIGNAL(result(KJob*)), SLOT(slotItemSyncDone(KJob*)) );
+    connect( d->mItemSyncer, SIGNAL( percent( KJob*, unsigned long ) ), SLOT( slotPercent( KJob*, unsigned long ) ) );
+    connect( d->mItemSyncer, SIGNAL( result( KJob* ) ), SLOT( slotItemSyncDone( KJob* ) ) );
   }
   d->mItemSyncer->setFullSyncItems( items );
 }
 
-void ResourceBase::itemsRetrievedIncremental(const Item::List &changedItems, const Item::List &removedItems)
+void ResourceBase::itemsRetrievedIncremental( const Item::List &changedItems, const Item::List &removedItems )
 {
   Q_D( ResourceBase );
   Q_ASSERT_X( d->scheduler->currentTask().type == ResourceScheduler::SyncCollection,
@@ -476,8 +580,8 @@ void ResourceBase::itemsRetrievedIncremental(const Item::List &changedItems, con
               "Calling itemsRetrievedIncremental() although no item retrieval is in progress" );
   if ( !d->mItemSyncer ) {
     d->mItemSyncer = new ItemSync( currentCollection() );
-    connect( d->mItemSyncer, SIGNAL(percent(KJob*,unsigned long)), SLOT(slotPercent(KJob*,unsigned long)) );
-    connect( d->mItemSyncer, SIGNAL(result(KJob*)), SLOT(slotItemSyncDone(KJob*)) );
+    connect( d->mItemSyncer, SIGNAL( percent( KJob*, unsigned long ) ), SLOT( slotPercent( KJob*, unsigned long ) ) );
+    connect( d->mItemSyncer, SIGNAL( result( KJob* ) ), SLOT( slotItemSyncDone( KJob* ) ) );
   }
   d->mItemSyncer->setIncrementalSyncItems( changedItems, removedItems );
 }
