@@ -42,6 +42,7 @@
 
 #include <gpgme.h>
 
+#include <istream>
 #ifndef NDEBUG
 #include <iostream>
 using std::cerr;
@@ -51,6 +52,10 @@ using std::endl;
 #include <cassert>
 
 namespace GpgME {
+  void initializeLibrary() {
+      gpgme_check_version( 0 );
+  }
+
   static inline gpgme_error_t makeError( gpg_err_code_t code ) {
     return gpg_err_make( (gpg_err_source_t)22, code );
   }
@@ -84,6 +89,10 @@ namespace GpgME {
     return code() == GPG_ERR_CANCELED;
   }
 
+  std::ostream & operator<<( std::ostream & os, const Error & err ) {
+      return os << "GpgME::Error(" << err.encodedError() << " (" << err.asString() << "))";
+  }
+
   Context::Context( gpgme_ctx_t ctx ) {
     d = new Private( ctx );
   }
@@ -700,11 +709,19 @@ namespace GpgME {
     unsigned int result = 0;
     if ( flags & Context::AlwaysTrust )
       result |= GPGME_ENCRYPT_ALWAYS_TRUST;
+#ifdef HAVE_GPGME_ENCRYPT_NO_ENCRYPT_TO
+    if ( flags & Context::NoEncryptTo )
+      result |= GPGME_ENCRYPT_NO_ENCRYPT_TO;
+#endif
     return static_cast<gpgme_encrypt_flags_t>( result );
   }
 
   EncryptionResult Context::encrypt( const std::vector<Key> & recipients, const Data & plainText, Data & cipherText, EncryptionFlags flags ) {
     d->lastop = Private::Encrypt;
+#ifndef HAVE_GPGME_ENCRYPT_NO_ENCRYPT_TO
+    if ( flags & NoEncryptTo )
+        return EncryptionResult( Error( d->lasterr = gpg_error( GPG_ERR_NOT_IMPLEMENTED ) ) );
+#endif
     const Data::Private * const pdp = plainText.impl();
     Data::Private * const cdp = cipherText.impl();
     gpgme_key_t * const keys = new gpgme_key_t[ recipients.size() + 1 ];
@@ -729,6 +746,10 @@ namespace GpgME {
 
   Error Context::startEncryption( const std::vector<Key> & recipients, const Data & plainText, Data & cipherText, EncryptionFlags flags ) {
     d->lastop = Private::Encrypt;
+#ifndef HAVE_GPGME_ENCRYPT_NO_ENCRYPT_TO
+    if ( flags & NoEncryptTo )
+        return Error( d->lasterr = gpg_error( GPG_ERR_NOT_IMPLEMENTED ) );
+#endif
     const Data::Private * const pdp = plainText.impl();
     Data::Private * const cdp = cipherText.impl();
     gpgme_key_t * const keys = new gpgme_key_t[ recipients.size() + 1 ];
@@ -810,6 +831,112 @@ namespace GpgME {
     return Error( d->lasterr );
   }
 
+  std::ostream & operator<<( std::ostream & os, Protocol proto ) {
+      os << "GpgME::Protocol(";
+      switch ( proto ) {
+      case OpenPGP:
+          os << "OpenPGP";
+          break;
+      case CMS:
+          os << "CMS";
+          break;
+      default:
+      case UnknownProtocol:
+          os << "UnknownProtocol";
+          break;
+      }
+      return os << ')';
+  }
+
+  std::ostream & operator<<( std::ostream & os, Engine eng ) {
+      os << "GpgME::Engine(";
+      switch ( eng ) {
+      case GpgEngine:
+          os << "GpgEngine";
+          break;
+      case GpgSMEngine:
+          os << "GpgSMEngine";
+          break;
+      case GpgConfEngine:
+          os << "GpgConfEngine";
+          break;
+      case AssuanEngine:
+          os << "AssuanEngine";
+      default:
+      case UnknownEngine:
+          os << "UnknownEngine";
+          break;
+      }
+      return os << ')';
+  }
+
+  std::ostream & operator<<( std::ostream & os, Context::CertificateInclusion incl ) {
+      os << "GpgME::Context::CertificateInclusion(" << static_cast<int>( incl );
+      switch ( incl ) {
+      case Context::DefaultCertificates:
+          os << "(DefaultCertificates)";
+          break;
+      case Context::AllCertificatesExceptRoot:
+          os << "(AllCertificatesExceptRoot)";
+          break;
+      case Context::AllCertificates:
+          os << "(AllCertificates)";
+          break;
+      case Context::NoCertificates:
+          os << "(NoCertificates)";
+          break;
+      case Context::OnlySenderCertificate:
+          os << "(OnlySenderCertificate)";
+          break;
+      }
+      return os << ')';
+  }
+
+  std::ostream & operator<<( std::ostream & os, KeyListMode mode ) {
+      os << "GpgME::KeyListMode(";
+#define CHECK( x ) if ( !(mode & (x)) ) {} else do { os << #x " "; } while (0)
+      CHECK( Local );
+      CHECK( Extern );
+      CHECK( Signatures );
+      CHECK( Validate );
+      CHECK( Ephemeral );
+#undef CHECK
+      return os << ')';
+  }
+
+  std::ostream & operator<<( std::ostream & os, SignatureMode mode ) {
+      os << "GpgME::SignatureMode(";
+      switch ( mode ) {
+#define CHECK( x ) case x: os << #x; break
+          CHECK( NormalSignatureMode );
+          CHECK( Detached );
+          CHECK( Clearsigned );
+#undef CHECK
+      default:
+          os << "???" "(" << static_cast<int>( mode ) << ')';
+          break;
+      }
+      return os << ')';
+  }
+
+  std::ostream & operator<<( std::ostream & os, Context::EncryptionFlags flags ) {
+      os << "GpgME::Context::EncryptionFlags(";
+#define CHECK( x ) if ( !(flags & (Context::x)) ) {} else do { os << #x " "; } while (0) 
+     CHECK( AlwaysTrust );
+#undef CHECK
+      return os << ')';
+  }
+
+  std::ostream & operator<<( std::ostream & os, Context::AuditLogFlags flags ) {
+      os << "GpgME::Context::AuditLogFlags(";
+#define CHECK( x ) if ( !(flags & (Context::x)) ) {} else do { os << #x " "; } while (0)
+      CHECK( HtmlAuditLog );
+      CHECK( AuditLogWithHelp );
+#undef CHECK
+      return os << ')';
+  }
+
+
 
 } // namespace GpgME
 
@@ -846,6 +973,14 @@ static gpgme_protocol_t engine2protocol( const GpgME::Engine engine ) {
     case GpgME::GpgConfEngine:
 #ifdef HAVE_GPGME_PROTOCOL_GPGCONF
         return GPGME_PROTOCOL_GPGCONF;
+#else
+        break;
+#endif
+    case GpgME::AssuanEngine:
+#ifdef HAVE_GPGME_ASSUAN_ENGINE
+        return GPGME_PROTOCOL_ASSUAN;
+#else
+        break;
 #endif
     case GpgME::UnknownEngine:
         ;
@@ -939,6 +1074,18 @@ static const unsigned long supported_features = 0
 #endif
 #ifdef HAVE_GPGME_CANCEL_ASYNC
     | GpgME::CancelOperationAsyncFeature
+#endif
+#ifdef HAVE_GPGME_ENCRYPT_NO_ENCRYPT_TO
+    | GpgME::NoEncryptToEncryptionFlagFeature
+#endif
+#ifdef HAVE_GPGME_SUBKEY_T_IS_CARDKEY
+    | GpgME::CardKeyFeature
+#endif
+#ifdef HAVE_GPGME_ASSUAN_ENGINE
+    | GpgME::AssuanEngineFeature
+#endif
+#ifdef HAVE_GPGME_KEYLIST_MODE_EPHEMERAL
+    | GpgME::EphemeralKeylistModeFeature
 #endif
     ;
 
