@@ -59,10 +59,7 @@ using namespace KCal;
 class KCal::CalendarLocal::Private
 {
   public:
-    Private()
-    {
-      mDeletedIncidences.setAutoDelete( true );
-    }
+    Private() {}
     QString mFileName;                     // filename where calendar is stored
     CalFormat *mFormat;                    // calendar format
 
@@ -72,7 +69,6 @@ class KCal::CalendarLocal::Private
     QMultiHash<QString, Todo*>mTodosForDate;// on due dates for all Todos
     QHash<QString, Journal *>mJournals;    // hash on uids of all Journals
     QMultiHash<QString, Journal *>mJournalsForDate; // on dates of all Journals
-    Incidence::List mDeletedIncidences;    // list of all deleted Incidences
 
     void insertEvent( Event *event );
     void insertTodo( Todo *todo );
@@ -168,7 +164,6 @@ void CalendarLocal::close()
   deleteAllTodos();
   deleteAllJournals();
 
-  d->mDeletedIncidences.clearAll();
   setModified( false );
 
   setObserversEnabled( true );
@@ -193,7 +188,6 @@ bool CalendarLocal::deleteEvent( Event *event )
   if ( d->mEvents.remove( uid ) ) {
     setModified( true );
     notifyIncidenceDeleted( event );
-    d->mDeletedIncidences.append( event );
     if ( !event->recurs() ) {
       removeIncidenceFromMultiHashByUID<Event *>(
         d->mEventsForDate, event->dtStart().date().toString(), event->uid() );
@@ -269,7 +263,6 @@ bool CalendarLocal::deleteTodo( Todo *todo )
   if ( d->mTodos.remove( todo->uid() ) ) {
     setModified( true );
     notifyIncidenceDeleted( todo );
-    d->mDeletedIncidences.append( todo );
     if ( todo->hasDueDate() ) {
       removeIncidenceFromMultiHashByUID<Todo *>(
         d->mTodosForDate, todo->dtDue().date().toString(), todo->uid() );
@@ -319,8 +312,8 @@ Todo::List CalendarLocal::rawTodosForDate( const QDate &date )
   Todo *t;
 
   QString dateStr = date.toString();
-  QMultiHash<QString, Todo *>::iterator it = d->mTodosForDate.find( dateStr );
-  while ( it != d->mTodosForDate.end() && it.key() == dateStr ) {
+  QMultiHash<QString, Todo *>::const_iterator it = d->mTodosForDate.constFind( dateStr );
+  while ( it != d->mTodosForDate.constEnd() && it.key() == dateStr ) {
     t = it.value();
     todoList.append( t );
     ++it;
@@ -427,11 +420,11 @@ Event::List CalendarLocal::rawEventsForDate( const QDate &date,
 
   // Find the hash for the specified date
   QString dateStr = date.toString();
-  QMultiHash<QString, Event *>::iterator it = d->mEventsForDate.find( dateStr );
+  QMultiHash<QString, Event *>::const_iterator it = d->mEventsForDate.constFind( dateStr );
   // Iterate over all non-recurring, single-day events that start on this date
   KDateTime::Spec ts = timespec.isValid() ? timespec : timeSpec();
   KDateTime kdt( date, ts );
-  while ( it != d->mEventsForDate.end() && it.key() == dateStr ) {
+  while ( it != d->mEventsForDate.constEnd() && it.key() == dateStr ) {
     ev = it.value();
     KDateTime end( ev->dtEnd().toTimeSpec( ev->dtStart() ) );
     if ( ev->allDay() ) {
@@ -453,7 +446,7 @@ Event::List CalendarLocal::rawEventsForDate( const QDate &date,
     if ( ev->recurs() ) {
       if ( ev->isMultiDay() ) {
         int extraDays = ev->dtStart().date().daysTo( ev->dtEnd().date() );
-        for ( int i = 0; i <= extraDays; i++ ) {
+        for ( int i = 0; i <= extraDays; ++i ) {
           if ( ev->recursOn( date.addDays( -i ), ts ) ) {
             eventList.append( ev );
             break;
@@ -588,7 +581,6 @@ bool CalendarLocal::deleteJournal( Journal *journal )
   if ( d->mJournals.remove( journal->uid() ) ) {
     setModified( true );
     notifyIncidenceDeleted( journal );
-    d->mDeletedIncidences.append( journal );
     removeIncidenceFromMultiHashByUID<Journal *>(
       d->mJournalsForDate, journal->dtStart().date().toString(), journal->uid() );
     return true;
@@ -636,9 +628,9 @@ Journal::List CalendarLocal::rawJournalsForDate( const QDate &date )
   Journal *j;
 
   QString dateStr = date.toString();
-  QMultiHash<QString, Journal *>::iterator it = d->mJournalsForDate.find( dateStr );
+  QMultiHash<QString, Journal *>::const_iterator it = d->mJournalsForDate.constFind( dateStr );
 
-  while ( it != d->mJournalsForDate.end() && it.key() == dateStr ) {
+  while ( it != d->mJournalsForDate.constEnd() && it.key() == dateStr ) {
     j = it.value();
     journalList.append( j );
     ++it;
