@@ -629,7 +629,7 @@ void ICalFormatImpl::Private::writeCustomProperties( icalcomponent *parent,
     if ( !c.key().startsWith( "X-KDE" ) &&          //krazy:exclude=strings
          !c.key().startsWith( "X-LibKCal" ) &&      //krazy:exclude=strings
          !c.key().startsWith( "X-MICROSOFT" ) &&    //krazy:exclude=strings
-         !c.key().startsWith( "X-MOZILLA" ) &&      //krazy:exclude=strings
+         !c.key().startsWith( "X-MOZ" ) &&          //krazy:exclude=strings
          !c.key().startsWith( "X-PILOT" ) ) {       //krazy:exclude=strings
       // use text values for the typical X-FOO property.
       // except for vendor specific X-FOO properties.
@@ -1440,8 +1440,8 @@ Attachment *ICalFormatImpl::readAttachment( icalproperty *attach )
 
     p = icalproperty_get_first_parameter( attach, ICAL_X_PARAMETER );
     while ( p ) {
-      if ( strncmp ( icalparameter_get_xname( p ), "X-LABEL", 7 ) == 0 ) {
-       attachment->setLabel( icalparameter_get_xvalue( p ) );
+      if ( strncmp( icalparameter_get_xname( p ), "X-LABEL", 7 ) == 0 ) {
+        attachment->setLabel( QString::fromUtf8( icalparameter_get_xvalue( p ) ) );
       }
       p = icalproperty_get_next_parameter( attach, ICAL_X_PARAMETER );
     }
