@@ -1541,11 +1541,13 @@ static QString formatICalInvitationHelper( QString invitation, Calendar *mCalend
   {
     if ( incidence && incidence->revision() > 0 && ( existingIncidence || !helper->calendar() ) ) {
       html += tdOpen;
-      if ( incBase->type() == "Todo" ) {
-        //TODO: 4.4, remove the []
-        html += helper->makeLink( "reply", i18n( "[Enter this into my to-do list]" ) );
-      } else {
-        html += helper->makeLink( "reply", i18n( "[Enter this into my calendar]" ) );
+      if ( incBase ) {
+        if ( incBase->type() == "Todo" ) {
+          //TODO: 4.4, remove the []
+          html += helper->makeLink( "reply", i18n( "[Enter this into my to-do list]" ) );
+        } else {
+          html += helper->makeLink( "reply", i18n( "[Enter this into my calendar]" ) );
+        }
       }
       html += tdClose;
     }
@@ -1589,7 +1591,7 @@ static QString formatICalInvitationHelper( QString invitation, Calendar *mCalend
       html += tdClose;
 
       // Check in calendar
-      if ( incBase->type() == "Event" ) {
+      if ( incBase && incBase->type() == "Event" ) {
         html += tdOpen;
         //TODO: 4.4, remove the []
         //TODO: 4.4, change to "Check calendar"
@@ -1613,10 +1615,12 @@ static QString formatICalInvitationHelper( QString invitation, Calendar *mCalend
     html += tdOpen;
     //TODO: 4.4, remove the []
     //TODO: 4.4, change string to "Enter this response into my..."
-    if ( incBase->type() == "Todo" ) {
-      html += helper->makeLink( "reply", i18n( "[Enter this into my to-do list]" ) );
-    } else {
-      html += helper->makeLink( "reply", i18n( "[Enter this into my calendar]" ) );
+    if ( incBase ) {
+      if ( incBase->type() == "Todo" ) {
+        html += helper->makeLink( "reply", i18n( "[Enter this into my to-do list]" ) );
+      } else {
+        html += helper->makeLink( "reply", i18n( "[Enter this into my calendar]" ) );
+      }
     }
     html += tdClose;
     break;
@@ -2228,7 +2232,7 @@ QString IncidenceFormatter::recurrenceString( Incidence *incidence )
                     "Recurs every <numid>%1</numid> months on the %2 %3 until %4",
                     recur->frequency(),
                     dayList[rule.pos() + 31],
-                    calSys->weekDayName( rule.day(),KCalendarSystem::LongDayName ),
+                    calSys->weekDayName( rule.day(), KCalendarSystem::LongDayName ),
                     recurEnd( incidence ) );
       if ( recur->duration() >  0 ) {
         txt += i18nc( "number of occurrences",
@@ -2270,20 +2274,22 @@ QString IncidenceFormatter::recurrenceString( Incidence *incidence )
   case Recurrence::rYearlyMonth:
   {
     if ( recur->duration() != -1 ) {
-      txt = i18ncp( "Recurs Every N years on month-name [1st|2nd|...]"
-                    " until end-date",
-                    "Recurs yearly on %2 %3 until %4",
-                    "Recurs every %1 years on %2 %3 until %4",
-                    recur->frequency(),
-                    calSys->monthName( recur->yearMonths()[0], recur->startDate().year() ),
-                    dayList[ recur->yearDates()[0] + 31 ],
-                    recurEnd( incidence ) );
-      if ( recur->duration() >  0 ) {
-        txt += i18nc( "number of occurrences",
-                      " (<numid>%1</numid> occurrences)",
-                      recur->duration() );
+      if ( !recur->yearDates().isEmpty() ) {
+        txt = i18ncp( "Recurs Every N years on month-name [1st|2nd|...]"
+                      " until end-date",
+                      "Recurs yearly on %2 %3 until %4",
+                      "Recurs every %1 years on %2 %3 until %4",
+                      recur->frequency(),
+                      calSys->monthName( recur->yearMonths()[0], recur->startDate().year() ),
+                      dayList[ recur->yearDates()[0] + 31 ],
+                      recurEnd( incidence ) );
+        if ( recur->duration() >  0 ) {
+          txt += i18nc( "number of occurrences",
+                        " (<numid>%1</numid> occurrences)",
+                        recur->duration() );
+        }
+        return txt;
       }
-      return txt;
     }
     if ( !recur->yearDates().isEmpty() ) {
       return i18ncp( "Recurs Every N years on month-name [1st|2nd|...]",
