@@ -26,12 +26,13 @@
 #include <kdialog.h>
 #include <klineedit.h>
 #include <kurlrequester.h>
-#include <krichtextwidget.h>
 #include <kshellcompletion.h>
 #include <ktoolbar.h>
 #include <krun.h>
 #include <KComboBox>
 
+#include <kpimtextedit/textedit.h>
+
 #include <QCheckBox>
 #include <QDir>
 #include <QFileInfo>
@@ -141,7 +142,7 @@ SignatureConfigurator::SignatureConfigurator( QWidget * parent )
     mFormatToolBar->setToolButtonStyle( Qt::ToolButtonIconOnly );
     page_vlay->addWidget( mFormatToolBar, 1 );
 
-    mTextEdit = new KRichTextWidget( this );
+    mTextEdit = new KPIMTextEdit::TextEdit( this );
     page_vlay->addWidget( mTextEdit, 2 );
     mTextEdit->setWhatsThis( i18n("Use this field to enter an arbitrary static signature."));
     // exclude SupportToPlainText.
@@ -322,13 +323,23 @@ SignatureConfigurator::SignatureConfigurator( QWidget * parent )
   Signature SignatureConfigurator::signature() const
   {
     Signature sig;
-    sig.setType( signatureType() );
-    sig.setInlinedHtml( d->inlinedHtml );
-    sig.setText( d->inlinedHtml ? asCleanedHTML() : mTextEdit->textOrHtml() );
-    if ( signatureType() == Signature::FromCommand )
+    const Signature::Type sigType = signatureType();
+    switch ( sigType ) {
+    case Signature::Inlined:
+      sig.setInlinedHtml( d->inlinedHtml );
+      sig.setText( d->inlinedHtml ? asCleanedHTML() : mTextEdit->textOrHtml() );
+      break;
+    case Signature::FromCommand:
       sig.setUrl( commandURL(), true );
-    if ( signatureType() == Signature::FromFile )
+      break;
+    case Signature::FromFile:
       sig.setUrl( fileURL(), false );
+      break;
+    case Signature::Disabled:
+      /* do nothing */
+      break;
+    }
+    sig.setType( sigType );
     return sig;
   }
 
